==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sr/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "ИП група адреса $1 је обрисана.");
regGS("IP Group $1 added for user $2", "ИП група $1 додата за корисника $2 ");
regGS("User permissions for $1 changed", "Корисничка права за $1 су промењена");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Рубрика $1 обрисана. (Издање: $2, публикација: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Рубрика $1 додата. (Издање: $2, публикација: $3)");
regGS("Issue $1 changed status to $2", "Издању $1 промењен статус у $2");
regGS("User type $1 deleted", "Тип корисника $1 је обрисан");
regGS("User type $1 added", "Тип корисника $1 је додат");
regGS("Topic $1 added to article", "Тема $1 је додата чланку");
regGS("Last", "Последњи");
regGS("First", "Први");
regGS("Changed image properties of $1", "Промењене особине слике $1");
regGS("Article topic $1 deleted", "Тема чланка $1 је обрисана");
regGS("Article #$1 \"$2\" ($3) created.", "Чланак #$1 \"$2\" ($3) је креиран.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Чланак #$1 \"$2\" ($3) је преведен у \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Чланак #$1 \"$2\" ($3) је прекопиран у #$3");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Статус чланка #$1: \"$2\" је промењен из $3 у $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Чланак #$1: \"$2\" ($3) је обрисан.");
regGS("Text", "текст");
regGS("Article body", "Сложен текст");
regGS("The default subscription time for $1 has been added.", "Нови период претплате за $1 додат");
regGS("Image $1 linked to article $2", "Слика $1 јењ повезана са чланком $2.");
regGS("Image $1 unlinked from $2", "Веза слика $1 са чланком $2 је раскинута");
regGS("The image $1 has been added.", "Слика $1 је додата");
regGS("Image $1 deleted", "Слика $1 је обрисана");
regGS("Publication $1 changed", "Публикација $1 промењена");
regGS("Publication $1 deleted", "Публикација $1 обрисана");
regGS("Publication $1 added", "Публикација $1 је додата");
regGS("Issue $1 from publication $2 deleted", "Издање $1 из публикације $2 обрисано");
regGS("Issue $1 added in publication $2", "Издање $1 додато у публикацију $2");
regGS("The article type $1 has been deleted.", "Тип чланка $1 је обрисан");
regGS("The article type $1 has been added.", "Тип чланка $1 је додат");
regGS("Article type field $1 created", "Поље $1 за тип чланка креирано");
regGS("Article type field $1 deleted", "Поље $1 типа чланка  је обрисано");
regGS("Language $1 added", "Додат је језик $1");
regGS("Language $1 deleted", "Језик $1 је обрисан");
regGS("Language $1 modified", "Језик $1 је модификован");
regGS("Country $1 added", "Држава $1 је додата");
regGS("Country $1 deleted", "Држава $1 је обрисана");
regGS("Country name $1 changed", "Име државе $1 промењено");
regGS("The user account $1 has been deleted.", "Кориснички налог $1 је обрисан");
regGS("Password changed for $1", "Промењена је лозинка за $1");
regGS("User account $1 created", "Креиран кориснички налог за $1");
regGS("Template $1 uploaded", "Шаблон $1 је аплоудован");
?>

==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sr/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "");
regGS("Field $1 updated", "");
regGS("Could not delete record from the database.", "");
regGS("template path", "");
regGS("short names", "");
regGS("Unable to fetch image from remote server.", "");
regGS("The article type field $1 has been renamed to $2.", "");
regGS("The article type $1 has been renamed to $2.", "");
regGS("Article type field $1 changed", "");
regGS("Article Type $1 translation updated", "");
regGS("The IP address group $1 has been deleted.", "ИП група адреса $1 је обрисана.");
regGS("IP Group $1 added for user $2", "ИП група $1 додата за корисника $2 ");
regGS("User permissions for $1 changed", "Корисничка права за $1 су промењена");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Рубрика $1 обрисана. (Издање: $2, публикација: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Рубрика $1 додата. (Издање: $2, публикација: $3)");
regGS("Issue $1 changed status to $2", "Издању $1 промењен статус у $2");
regGS("User type $1 deleted", "Тип корисника $1 је обрисан");
regGS("User type $1 added", "Тип корисника $1 је додат");
regGS("Topic $1 added to article", "Тема $1 је додата чланку");
regGS("Last", "Последњи");
regGS("First", "Први");
regGS("Changed image properties of $1", "Промењене особине слике $1");
regGS("Article topic $1 deleted", "Тема чланка $1 је обрисана");
regGS("Article #$1 \"$2\" ($3) created.", "Чланак #$1 \"$2\" ($3) је креиран.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Чланак #$1 \"$2\" ($3) је преведен у \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Чланак #$1 \"$2\" ($3) је прекопиран у #$3");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Статус чланка #$1: \"$2\" је промењен из $3 у $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Чланак #$1: \"$2\" ($3) је обрисан.");
regGS("Single-line Text", "текст");
regGS("Multi-line Text with WYSIWYG", "Сложен текст");
regGS("The default subscription time for $1 has been added.", "Нови период претплате за $1 додат");
regGS("Image $1 linked to article $2", "Слика $1 јењ повезана са чланком $2.");
regGS("Image $1 unlinked from $2", "Веза слика $1 са чланком $2 је раскинута");
regGS("The image $1 has been added.", "Слика $1 је додата");
regGS("Image $1 deleted", "Слика $1 је обрисана");
regGS("Publication $1 changed", "Публикација $1 промењена");
regGS("Publication $1 deleted", "Публикација $1 обрисана");
regGS("Publication $1 added", "Публикација $1 је додата");
regGS("Issue $1 from publication $2 deleted", "Издање $1 из публикације $2 обрисано");
regGS("Issue $1 added in publication $2", "Издање $1 додато у публикацију $2");
regGS("The article type $1 has been deleted.", "Тип чланка $1 је обрисан");
regGS("The article type $1 has been added.", "Тип чланка $1 је додат");
regGS("Article type field $1 created", "Поље $1 за тип чланка креирано");
regGS("Article type field $1 deleted", "Поље $1 типа чланка  је обрисано");
regGS("Language $1 added", "Додат је језик $1");
regGS("Language $1 deleted", "Језик $1 је обрисан");
regGS("Language $1 modified", "Језик $1 је модификован");
regGS("Country $1 added", "Држава $1 је додата");
regGS("Country $1 deleted", "Држава $1 је обрисана");
regGS("Country name $1 changed", "Име државе $1 промењено");
regGS("The user account $1 has been deleted.", "Кориснички налог $1 је обрисан");
regGS("Password changed for $1", "Промењена је лозинка за $1");
regGS("User account $1 created", "Креиран кориснички налог за $1");
regGS("Template $1 uploaded", "Шаблон $1 је аплоудован");
regGS("URL \"$1\" is invalid or is not an image.", "УРЛ \"$1\"је неисправан или није слика");
regGS("URL \"$1\" is not an image.", "УРЛ \"$1\" није слика.");
regGS("Topic $1 added", "Тема $1 је додата");
regGS("Topic $1 deleted", "Тема $1 је обрисана");
regGS("Topic $1 updated", "Тема $1 измењена");
?>
